Module extract

Module extract 

Functions

extract
Extract string messages from React components that use react-intl
extract_base_dir
Extract the base directory from a glob pattern (the prefix before the first wildcard). For example, src/components/**/*.ts returns src/components. If the pattern starts with a wildcard, returns . (current directory).
extract_to_string