Functions
- extract
- Extract string messages from React components that use react-intl
- extract_
base_ dir - Extract the base directory from a glob pattern (the prefix before the first wildcard).
For example,
src/components/**/*.tsreturnssrc/components. If the pattern starts with a wildcard, returns.(current directory). - extract_
to_ string